==> s-contract-1.0.2-4.tgz: package/borsh.js <==
// Copyright 2021-2022 @skyekiwi/s-contract authors & contributors
// SPDX-License-Identifier: Apache-2.0

import { baseDecode, baseEncode, deserialize, serialize } from 'borsh';

/* eslint-disable sort-keys, camelcase */
class Call {
  // public transaction_action: 'create_account' | 'call' | 'transfer' | 'view_method_call' | 'deploy'

  constructor(config) {
    this.origin_public_key = void 0;
    this.receipt_public_key = void 0;
    this.encrypted_egress = void 0;
    this.transaction_action = void 0;
    this.amount = void 0;
    this.contract_name = void 0;
    this.method = void 0;
    this.args = void 0;
    this.wasm_code = void 0;
    this.origin_public_key = config.origin_public_key;
    this.receipt_public_key = config.receipt_public_key;
    this.encrypted_egress = config.encrypted_egress;
    this.transaction_action = config.transaction_action;
    this.amount = config.amount;
    this.contract_name = config.contract_name;
    this.method = config.method;
    this.args = config.args;
    this.wasm_code = config.wasm_code;
  }
}
class Calls {
  constructor(config) {
    this.ops = void 0;
    this.shard_id = void 0;
    this.block_number = void 0;
    this.ops = config.ops;
    this.shard_id = config.shard_id;
    this.block_number = config.block_number;
  }
}
class Outcome {
  constructor(config) {
    this.view_result_log = void 0;
    this.view_result = void 0;
    this.view_error = void 0;
    this.outcome_logs = void 0;
    this.outcome_token_burnt = void 0;
    this.outcome_status = void 0;
    this.encrypted = void 0;
    this.view_result_log = config.view_result_log;
    this.view_result = config.view_result;
    this.view_error = config.view_error;
    this.outcome_logs = config.outcome_logs;
    this.outcome_token_burnt = config.outcome_token_burnt;
    this.outcome_status = config.outcome_status;
    this.encrypted = config.encrypted;
  }
}
class Outcomes {
  constructor(config) {
    this.ops = void 0;
    this.call_index = void 0;
    this.signature = void 0;
    this.state_root = void 0;
    this.ops = config.ops;
    this.call_index = config.call_index;
    this.signature = config.signature;
    this.state_root = config.state_root;
  }
}
const callSchema = new Map([[Call, {
  kind: 'struct',
  fields: [['origin_public_key', ['u8', 32]], ['receipt_public_key', ['u8', 32]], ['encrypted_egress', 'u8'], ['transaction_action', 'u8'], ['amount', {
    kind: 'option',
    type: 'u32'
  }], ['contract_name', {
    kind: 'option',
    type: ['u8']
  }], ['method', {
    kind: 'option',
    type: ['u8']
  }], ['args', {
    kind: 'option',
    type: ['u8']
  }], ['wasm_code', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
const callsSchema = new Map();
callsSchema.set(Calls, {
  kind: 'struct',
  fields: [['ops', [Call]], ['shard_id', 'u32'], ['block_number', {
    kind: 'option',
    type: 'u32'
  }]]
});
callsSchema.set(Call, callSchema.get(Call));
const outcomeSchema = new Map([[Outcome, {
  kind: 'struct',
  fields: [['view_result_log', [['u8']]], ['view_result', {
    kind: 'option',
    type: ['u8']
  }], ['view_error', {
    kind: 'option',
    type: ['u8']
  }], ['outcome_logs', [['u8']]], ['outcome_token_burnt', 'u32'], ['outcome_status', {
    kind: 'option',
    type: ['u8']
  }], ['encrypted', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
const outcomesSchema = new Map();
outcomesSchema.set(Outcomes, {
  kind: 'struct',
  fields: [['ops', [Outcome]], ['call_index', 'u32'], ['signature', ['u8', 64]], ['state_root', ['u8', 32]]]
});
outcomesSchema.set(Outcome, outcomeSchema.get(Outcome));

// ser
const buildCall = call => {
  return serialize(callSchema, call);
};
const buildCalls = calls => {
  return serialize(callsSchema, calls);
};
const buildOutcome = outcome => {
  return serialize(outcomeSchema, outcome);
};
const buildOutcomes = outcomes => {
  return serialize(outcomesSchema, outcomes);
};

// de
const parseCall = buf => {
  const c = deserialize(callSchema, Call, Buffer.from(buf));
  c.encrypted_egress = !!c.encrypted_egress;

  // c.origin_public_key = new Uint8Array(c.origin_public_key);
  // c.receipt_public_key = new Uint8Array(c.receipt_public_key);
  // c.contract_name = new Uint8Array(c.contract_name);
  // c.method = new Uint8Array(c.method);
  // c.args = new Uint8Array(c.args);
  // c.wasm_code = new Uint8Array(c.wasm_code);
  return c;
};
const parseCalls = buf => {
  const cs = deserialize(callsSchema, Calls, Buffer.from(buf));
  for (let i = 0; i < cs.ops.length; i++) {
    cs.ops[i].encrypted_egress = !!cs.ops[i].encrypted_egress;
  }
  return cs;
};
const parseOutcome = buf => {
  const o = deserialize(outcomeSchema, Outcome, Buffer.from(buf));
  return o;
};
const parseOutcomes = buf => {
  return deserialize(outcomesSchema, Outcomes, Buffer.from(buf));
};
export { Call, callSchema, buildCall, parseCall, Calls, callsSchema, buildCalls, parseCalls, Outcome, outcomeSchema, buildOutcome, parseOutcome, Outcomes, outcomesSchema, buildOutcomes, parseOutcomes, baseEncode, baseDecode };

==> s-contract-1.0.2-5.tgz: package/borsh.js <==
// Copyright 2021-2022 @skyekiwi/s-contract authors & contributors
// SPDX-License-Identifier: Apache-2.0

import { baseDecode, baseEncode, deserialize, serialize } from 'borsh';

/* eslint-disable sort-keys, camelcase */
class Call {
  // public transaction_action: 'create_account' | 'call' | 'transfer' | 'view_method_call' | 'deploy'

  constructor(config) {
    this.origin_public_key = void 0;
    this.receipt_public_key = void 0;
    this.encrypted_egress = void 0;
    this.transaction_action = void 0;
    this.amount = void 0;
    this.contract_name = void 0;
    this.method = void 0;
    this.args = void 0;
    this.wasm_code = void 0;
    this.origin_public_key = config.origin_public_key;
    this.receipt_public_key = config.receipt_public_key;
    this.encrypted_egress = config.encrypted_egress;
    this.transaction_action = config.transaction_action;
    this.amount = config.amount;
    this.contract_name = config.contract_name;
    this.method = config.method;
    this.args = config.args;
    this.wasm_code = config.wasm_code;
  }
}
class Calls {
  constructor(config) {
    this.ops = void 0;
    this.shard_id = void 0;
    this.block_number = void 0;
    this.ops = config.ops;
    this.shard_id = config.shard_id;
    this.block_number = config.block_number;
  }
}
class Outcome {
  constructor(config) {
    this.view_result_log = void 0;
    this.view_result = void 0;
    this.view_error = void 0;
    this.outcome_logs = void 0;
    this.outcome_token_burnt = void 0;
    this.outcome_status = void 0;
    this.encrypted = void 0;
    this.view_result_log = config.view_result_log;
    this.view_result = config.view_result;
    this.view_error = config.view_error;
    this.outcome_logs = config.outcome_logs;
    this.outcome_token_burnt = config.outcome_token_burnt;
    this.outcome_status = config.outcome_status;
    this.encrypted = config.encrypted;
  }
}
class Outcomes {
  constructor(config) {
    this.ops = void 0;
    this.call_index = void 0;
    this.signature = void 0;
    this.state_root = void 0;
    this.ops = config.ops;
    this.call_index = config.call_index;
    this.signature = config.signature;
    this.state_root = config.state_root;
  }
}
const callSchema = new Map([[Call, {
  kind: 'struct',
  fields: [['origin_public_key', ['u8', 32]], ['receipt_public_key', ['u8', 32]], ['encrypted_egress', 'u8'], ['transaction_action', 'u8'], ['amount', {
    kind: 'option',
    type: 'u32'
  }], ['contract_name', {
    kind: 'option',
    type: ['u8']
  }], ['method', {
    kind: 'option',
    type: ['u8']
  }], ['args', {
    kind: 'option',
    type: ['u8']
  }], ['wasm_code', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
const callsSchema = new Map();
callsSchema.set(Calls, {
  kind: 'struct',
  fields: [['ops', [Call]], ['shard_id', 'u32'], ['block_number', {
    kind: 'option',
    type: 'u32'
  }]]
});
callsSchema.set(Call, callSchema.get(Call));
const outcomeSchema = new Map([[Outcome, {
  kind: 'struct',
  fields: [['view_result_log', [['u8']]], ['view_result', {
    kind: 'option',
    type: ['u8']
  }], ['view_error', {
    kind: 'option',
    type: ['u8']
  }], ['outcome_logs', [['u8']]], ['outcome_token_burnt', 'u32'], ['outcome_status', {
    kind: 'option',
    type: ['u8']
  }], ['encrypted', {
    kind: 'option',
    type: ['u8']
  }]]
}]]);
const outcomesSchema = new Map();
outcomesSchema.set(Outcomes, {
  kind: 'struct',
  fields: [['ops', [Outcome]], ['call_index', 'u32'], ['signature', ['u8']], ['state_root', ['u8', 32]]]
});
outcomesSchema.set(Outcome, outcomeSchema.get(Outcome));

// ser
const buildCall = call => {
  return serialize(callSchema, call);
};
const buildCalls = calls => {
  return serialize(callsSchema, calls);
};
const buildOutcome = outcome => {
  return serialize(outcomeSchema, outcome);
};
const buildOutcomes = outcomes => {
  return serialize(outcomesSchema, outcomes);
};

// de
const parseCall = buf => {
  const c = deserialize(callSchema, Call, Buffer.from(buf));
  c.encrypted_egress = !!c.encrypted_egress;

  // c.origin_public_key = new Uint8Array(c.origin_public_key);
  // c.receipt_public_key = new Uint8Array(c.receipt_public_key);
  // c.contract_name = new Uint8Array(c.contract_name);
  // c.method = new Uint8Array(c.method);
  // c.args = new Uint8Array(c.args);
  // c.wasm_code = new Uint8Array(c.wasm_code);
  return c;
};
const parseCalls = buf => {
  const cs = deserialize(callsSchema, Calls, Buffer.from(buf));
  for (let i = 0; i < cs.ops.length; i++) {
    cs.ops[i].encrypted_egress = !!cs.ops[i].encrypted_egress;
  }
  return cs;
};
const parseOutcome = buf => {
  const o = deserialize(outcomeSchema, Outcome, Buffer.from(buf));
  return o;
};
const parseOutcomes = buf => {
  return deserialize(outcomesSchema, Outcomes, Buffer.from(buf));
};
export { Call, callSchema, buildCall, parseCall, Calls, callsSchema, buildCalls, parseCalls, Outcome, outcomeSchema, buildOutcome, parseOutcome, Outcomes, outcomesSchema, buildOutcomes, parseOutcomes, baseEncode, baseDecode };
